@@ -11,18 +11,18 @@ use Scalar::Util ();
 
 $Net::OAuth::PROTOCOL_VERSION = Net::OAuth::PROTOCOL_VERSION_1_0A;
 
-our $VERSION = '0.01'; # VERSION
+our $VERSION = '0.02'; # VERSION
 
 has access_token => (
     is       => 'rw',
     isa      => Str,
-    required => 1,
+    required => 0,
 );
 
 has access_token_secret => (
     is       => 'rw',
     isa      => Str,
-    required => 1,
+    required => 0,
 );
 
 has identifier => (
@@ -43,6 +43,12 @@ has consumer_secret => (
     required => 1,
 );
 
+has oauth_type => (
+    is       => 'rw',
+    isa      => Str,
+    default  => 'protected resource',
+);
+
 has version => (
     is       => 'rw',
     isa      => Str,
@@ -99,7 +105,7 @@ method PREPARE ($ua, $tx, %args) {
 
     # oauth object
     my $base  = $url->clone; $base->query(undef);
-    my $oauth = Net::OAuth->request('protected resource')->new(%$params,
+    my $oauth = Net::OAuth->request($self->oauth_type)->new(%$params,
         version          => '1.0',
         consumer_key     => $consumer_key,
         consumer_secret  => $consumer_secret,
@@ -111,7 +117,8 @@ method PREPARE ($ua, $tx, %args) {
         token_secret     => $access_token_secret,
         nonce            => Digest::SHA::sha1_base64(time . $$ . rand),
     );
- 
+
+    # oauth signature
     $oauth->sign;
 
     # authorization header
@@ -185,7 +192,7 @@ API::Twitter - Perl 5 API wrapper for Twitter.com
 
 =head1 VERSION
 
-version 0.01
+version 0.02
 
 =head1 SYNOPSIS
 
@@ -231,8 +238,8 @@ returned.
 
     my $user = $twitter->users('lookup');
 
-    $user->action; # GET   /users/lookup
-    $user->action('head'); # HEAD  /users/lookup
+    $user->action;          # GET /users/lookup
+    $user->action('head');  # HEAD /users/lookup
     $user->action('patch'); # PATCH /users/lookup
 
 Building up an HTTP request object is extremely easy, simply call method names
